@@ -5,7 +5,7 @@ use warnings;
 use namespace::autoclean;
 use autodie qw( :all );
 
-our $VERSION = '0.08';
+our $VERSION = '0.09';
 
 use App::CISetup::Travis::ConfigFile;
 use App::CISetup::Types qw( Bool Str );
@@ -26,6 +26,12 @@ has force_threaded_perls => (
     default => 0,
 );
 
+has perl_caching => (
+    is      => 'ro',
+    isa     => Bool,
+    default => 1,
+);
+
 has github_user => (
     is        => 'ro',
     isa       => Str,
@@ -50,6 +56,7 @@ sub _cli_params {
 
     return (
         force_threaded_perls => $self->force_threaded_perls,
+        perl_caching         => $self->perl_caching,
         (
             $self->has_email_address
             ? ( email_address => $self->email_address )
